@@ -1,9 +1,9 @@
 package Sah::Schemas::Firefox;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-06-04'; # DATE
+our $DATE = '2021-07-19'; # DATE
 our $DIST = 'Sah-Schemas-Firefox'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 1;
 # ABSTRACT: Various Sah schemas related to Firefox
@@ -20,7 +20,27 @@ Sah::Schemas::Firefox - Various Sah schemas related to Firefox
 
 =head1 VERSION
 
-This document describes version 0.002 of Sah::Schemas::Firefox (from Perl distribution Sah-Schemas-Firefox), released on 2020-06-04.
+This document describes version 0.003 of Sah::Schemas::Firefox (from Perl distribution Sah-Schemas-Firefox), released on 2021-07-19.
+
+=head1 CONTRIBUTOR
+
+=for stopwords perlancar (on pc-home)
+
+perlancar (on pc-home) <perlancar@gmail.com>
+
+=head1 SAH SCHEMAS
+
+=over
+
+=item * L<firefox::local_profile_name|Sah::Schema::firefox::local_profile_name>
+
+Firefox profile name, must exist in local Firefox installation.
+
+=item * L<firefox::profile_name|Sah::Schema::firefox::profile_name>
+
+Firefox profile name.
+
+=back
 
 =head1 HOMEPAGE
 
@@ -50,7 +70,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
